#!/bin/python3
# Copyright 2021 by opensource@secinfra.fr
# Initially from Matthew Treinish's https://github.com/mtreinish/pyopnsense
# Improved a bit.

#
# This file is part of pyopnsense2
#
# pyopnsense2 is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# pyopnsense2 is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with pyopnsense2. If not, see <http://www.gnu.org/licenses/>.

from pyopnsense2 import client
from six.moves import urllib
import json

class freeradius_avpair(client.BaseClient):
    """A client for interacting with the OPNSense's freeradiusavpair API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/net/freeradius/src/opnsense/mvc/app/models/OPNsense/Freeradius/Avpair.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addAvpair(self, args={}, params={}):
        """"""
        url = "freeradius/avpair/addAvpair/"
        data = {}

        data = self._post( url, args)
        return data

    def delAvpair(self, args={}, params={}):
        """"""
        url = "freeradius/avpair/delAvpair/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "freeradius/avpair/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getAvpair(self, args={}, params={}):
        """"""
        url = "freeradius/avpair/getAvpair/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchAvpair(self, args={}, params={}):
        """"""
        url = "freeradius/avpair/searchAvpair/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "freeradius/avpair/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setAvpair(self, args={}, params={}):
        """"""
        url = "freeradius/avpair/setAvpair/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleAvpair(self, args={}, params={}):
        """"""
        url = "freeradius/avpair/toggleAvpair/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

class freeradius_client(client.BaseClient):
    """A client for interacting with the OPNSense's freeradiusclient API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/net/freeradius/src/opnsense/mvc/app/models/OPNsense/Freeradius/Client.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addClient(self, args={}, params={}):
        """"""
        url = "freeradius/client/addClient/"
        data = {}

        data = self._post( url, args)
        return data

    def delClient(self, args={}, params={}):
        """"""
        url = "freeradius/client/delClient/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "freeradius/client/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getClient(self, args={}, params={}):
        """"""
        url = "freeradius/client/getClient/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchClient(self, args={}, params={}):
        """"""
        url = "freeradius/client/searchClient/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "freeradius/client/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setClient(self, args={}, params={}):
        """"""
        url = "freeradius/client/setClient/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleClient(self, args={}, params={}):
        """"""
        url = "freeradius/client/toggleClient/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

class freeradius_dhcp(client.BaseClient):
    """A client for interacting with the OPNSense's freeradiusdhcp API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/net/freeradius/src/opnsense/mvc/app/models/OPNsense/Freeradius/Dhcp.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addDhcp(self, args={}, params={}):
        """"""
        url = "freeradius/dhcp/addDhcp/"
        data = {}

        data = self._post( url, args)
        return data

    def delDhcp(self, args={}, params={}):
        """"""
        url = "freeradius/dhcp/delDhcp/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "freeradius/dhcp/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getDhcp(self, args={}, params={}):
        """"""
        url = "freeradius/dhcp/getDhcp/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchDhcp(self, args={}, params={}):
        """"""
        url = "freeradius/dhcp/searchDhcp/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "freeradius/dhcp/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setDhcp(self, args={}, params={}):
        """"""
        url = "freeradius/dhcp/setDhcp/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleDhcp(self, args={}, params={}):
        """"""
        url = "freeradius/dhcp/toggleDhcp/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

class freeradius_eap(client.BaseClient):
    """A client for interacting with the OPNSense's freeradiuseap API.
    for more information on used parameters, see : 

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def get(self, args={}, params={}):
        """"""
        url = "freeradius/eap/get/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "freeradius/eap/set/"
        data = {}

        data = self._post( url, args)
        return data

class freeradius_general(client.BaseClient):
    """A client for interacting with the OPNSense's freeradiusgeneral API.
    for more information on used parameters, see : 

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def get(self, args={}, params={}):
        """"""
        url = "freeradius/general/get/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "freeradius/general/set/"
        data = {}

        data = self._post( url, args)
        return data

class freeradius_ldap(client.BaseClient):
    """A client for interacting with the OPNSense's freeradiusldap API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/net/freeradius/src/opnsense/mvc/app/models/OPNsense/Freeradius/Ldap.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def get(self, args={}, params={}):
        """"""
        url = "freeradius/ldap/get/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "freeradius/ldap/set/"
        data = {}

        data = self._get( url, args)
        return data

class freeradius_lease(client.BaseClient):
    """A client for interacting with the OPNSense's freeradiuslease API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/net/freeradius/src/opnsense/mvc/app/models/OPNsense/Freeradius/Lease.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addLease(self, args={}, params={}):
        """"""
        url = "freeradius/lease/addLease/"
        data = {}

        data = self._post( url, args)
        return data

    def delLease(self, args={}, params={}):
        """"""
        url = "freeradius/lease/delLease/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "freeradius/lease/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getLease(self, args={}, params={}):
        """"""
        url = "freeradius/lease/getLease/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchLease(self, args={}, params={}):
        """"""
        url = "freeradius/lease/searchLease/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "freeradius/lease/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setLease(self, args={}, params={}):
        """"""
        url = "freeradius/lease/setLease/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleLease(self, args={}, params={}):
        """"""
        url = "freeradius/lease/toggleLease/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

class freeradius_service(client.BaseClient):
    """A client for interacting with the OPNSense's freeradiusservice API.
    for more information on used parameters, see : 

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def reconfigure(self, args={}, params={}):
        """"""
        url = "freeradius/service/reconfigure/"
        data = {}

        data = self._post( url, args)
        return data

    def restart(self, args={}, params={}):
        """"""
        url = "freeradius/service/restart/"
        data = {}

        data = self._post( url, args)
        return data

    def start(self, args={}, params={}):
        """"""
        url = "freeradius/service/start/"
        data = {}

        data = self._post( url, args)
        return data

    def status(self, args={}, params={}):
        """"""
        url = "freeradius/service/status/"
        data = {}

        data = self._get( url, args)
        return data

    def stop(self, args={}, params={}):
        """"""
        url = "freeradius/service/stop/"
        data = {}

        data = self._post( url, args)
        return data

class freeradius_user(client.BaseClient):
    """A client for interacting with the OPNSense's freeradiususer API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/net/freeradius/src/opnsense/mvc/app/models/OPNsense/Freeradius/User.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addUser(self, args={}, params={}):
        """"""
        url = "freeradius/user/addUser/"
        data = {}

        data = self._post( url, args)
        return data

    def delUser(self, args={}, params={}):
        """"""
        url = "freeradius/user/delUser/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "freeradius/user/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getUser(self, args={}, params={}):
        """"""
        url = "freeradius/user/getUser/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchUser(self, args={}, params={}):
        """"""
        url = "freeradius/user/searchUser/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "freeradius/user/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setUser(self, args={}, params={}):
        """"""
        url = "freeradius/user/setUser/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleUser(self, args={}, params={}):
        """"""
        url = "freeradius/user/toggleUser/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data



#!/bin/python3
# Copyright 2021 by opensource@secinfra.fr
# Initially from Matthew Treinish's https://github.com/mtreinish/pyopnsense
# Improved a bit.

#
# This file is part of pyopnsense2
#
# pyopnsense2 is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# pyopnsense2 is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with pyopnsense2. If not, see <http://www.gnu.org/licenses/>.

from pyopnsense2 import client
from six.moves import urllib
import json

class trafficshaper_service(client.BaseClient):
    """A client for interacting with the OPNSense's trafficshaperservice API.
    for more information on used parameters, see : 

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def flushreload(self, args={}, params={}):
        """"""
        url = "trafficshaper/service/flushreload/"
        data = {}

        data = self._post( url, args)
        return data

    def reconfigure(self, args={}, params={}):
        """"""
        url = "trafficshaper/service/reconfigure/"
        data = {}

        data = self._post( url, args)
        return data

    def statistics(self, args={}, params={}):
        """"""
        url = "trafficshaper/service/statistics/"
        data = {}

        data = self._get( url, args)
        return data

class trafficshaper_settings(client.BaseClient):
    """A client for interacting with the OPNSense's trafficshapersettings API.
    for more information on used parameters, see : ['https://github.com/opnsense/core/blob/master/src/opnsense/mvc/app/models/OPNsense/TrafficShaper/TrafficShaper.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addPipe(self, args={}, params={}):
        """"""
        url = "trafficshaper/settings/addPipe/"
        data = {}

        data = self._post( url, args)
        return data

    def addQueue(self, args={}, params={}):
        """"""
        url = "trafficshaper/settings/addQueue/"
        data = {}

        data = self._post( url, args)
        return data

    def addRule(self, args={}, params={}):
        """"""
        url = "trafficshaper/settings/addRule/"
        data = {}

        data = self._post( url, args)
        return data

    def delPipe(self, args={}, params={}):
        """"""
        url = "trafficshaper/settings/delPipe/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delQueue(self, args={}, params={}):
        """"""
        url = "trafficshaper/settings/delQueue/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delRule(self, args={}, params={}):
        """"""
        url = "trafficshaper/settings/delRule/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "trafficshaper/settings/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getPipe(self, args={}, params={}):
        """"""
        url = "trafficshaper/settings/getPipe/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getQueue(self, args={}, params={}):
        """"""
        url = "trafficshaper/settings/getQueue/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getRule(self, args={}, params={}):
        """"""
        url = "trafficshaper/settings/getRule/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchPipes(self, args={}, params={}):
        """"""
        url = "trafficshaper/settings/searchPipes/"
        data = {}

        data = self._get( url, args)
        return data

    def searchQueues(self, args={}, params={}):
        """"""
        url = "trafficshaper/settings/searchQueues/"
        data = {}

        data = self._get( url, args)
        return data

    def searchRules(self, args={}, params={}):
        """"""
        url = "trafficshaper/settings/searchRules/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "trafficshaper/settings/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setPipe(self, args={}, params={}):
        """"""
        url = "trafficshaper/settings/setPipe/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setQueue(self, args={}, params={}):
        """"""
        url = "trafficshaper/settings/setQueue/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setRule(self, args={}, params={}):
        """"""
        url = "trafficshaper/settings/setRule/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def togglePipe(self, args={}, params={}):
        """"""
        url = "trafficshaper/settings/togglePipe/"
        data = {}

        if "enabled" not in args.keys():
            return self.log_error("mandatory argument enabled is missing")
        else:
            url += args.pop("enabled")+"/"

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleQueue(self, args={}, params={}):
        """"""
        url = "trafficshaper/settings/toggleQueue/"
        data = {}

        if "enabled" not in args.keys():
            return self.log_error("mandatory argument enabled is missing")
        else:
            url += args.pop("enabled")+"/"

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleRule(self, args={}, params={}):
        """"""
        url = "trafficshaper/settings/toggleRule/"
        data = {}

        if "enabled" not in args.keys():
            return self.log_error("mandatory argument enabled is missing")
        else:
            url += args.pop("enabled")+"/"

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data



#!/bin/python3
# Copyright 2021 by opensource@secinfra.fr
# Initially from Matthew Treinish's https://github.com/mtreinish/pyopnsense
# Improved a bit.

#
# This file is part of pyopnsense2
#
# pyopnsense2 is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# pyopnsense2 is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with pyopnsense2. If not, see <http://www.gnu.org/licenses/>.

from pyopnsense2 import client
from six.moves import urllib
import json

class bind_acl(client.BaseClient):
    """A client for interacting with the OPNSense's bindacl API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/dns/bind/src/opnsense/mvc/app/models/OPNsense/Bind/Acl.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addAcl(self, args={}, params={}):
        """"""
        url = "bind/acl/addAcl/"
        data = {}

        data = self._post( url, args)
        return data

    def delAcl(self, args={}, params={}):
        """"""
        url = "bind/acl/delAcl/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "bind/acl/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getAcl(self, args={}, params={}):
        """"""
        url = "bind/acl/getAcl/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchAcl(self, args={}, params={}):
        """"""
        url = "bind/acl/searchAcl/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "bind/acl/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setAcl(self, args={}, params={}):
        """"""
        url = "bind/acl/setAcl/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleAcl(self, args={}, params={}):
        """"""
        url = "bind/acl/toggleAcl/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

class bind_dnsbl(client.BaseClient):
    """A client for interacting with the OPNSense's binddnsbl API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/dns/bind/src/opnsense/mvc/app/models/OPNsense/Bind/Dnsbl.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def get(self, args={}, params={}):
        """"""
        url = "bind/dnsbl/get/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "bind/dnsbl/set/"
        data = {}

        data = self._get( url, args)
        return data

class bind_domain(client.BaseClient):
    """A client for interacting with the OPNSense's binddomain API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/dns/bind/src/opnsense/mvc/app/models/OPNsense/Bind/Domain.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addDomain(self, args={}, params={}):
        """"""
        url = "bind/domain/addDomain/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delDomain(self, args={}, params={}):
        """"""
        url = "bind/domain/delDomain/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "bind/domain/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getDomain(self, args={}, params={}):
        """"""
        url = "bind/domain/getDomain/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchDomain(self, args={}, params={}):
        """"""
        url = "bind/domain/searchDomain/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "bind/domain/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setDomain(self, args={}, params={}):
        """"""
        url = "bind/domain/setDomain/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleDomain(self, args={}, params={}):
        """"""
        url = "bind/domain/toggleDomain/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

class bind_general(client.BaseClient):
    """A client for interacting with the OPNSense's bindgeneral API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/dns/bind/src/opnsense/mvc/app/models/OPNsense/Bind/General.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def get(self, args={}, params={}):
        """"""
        url = "bind/general/get/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "bind/general/set/"
        data = {}

        data = self._get( url, args)
        return data

class bind_record(client.BaseClient):
    """A client for interacting with the OPNSense's bindrecord API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/dns/bind/src/opnsense/mvc/app/models/OPNsense/Bind/Record.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addRecord(self, args={}, params={}):
        """"""
        url = "bind/record/addRecord/"
        data = {}

        data = self._post( url, args)
        return data

    def delRecord(self, args={}, params={}):
        """"""
        url = "bind/record/delRecord/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "bind/record/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getRecord(self, args={}, params={}):
        """"""
        url = "bind/record/getRecord/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchRecord(self, args={}, params={}):
        """"""
        url = "bind/record/searchRecord/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "bind/record/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setRecord(self, args={}, params={}):
        """"""
        url = "bind/record/setRecord/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleRecord(self, args={}, params={}):
        """"""
        url = "bind/record/toggleRecord/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

class bind_service(client.BaseClient):
    """A client for interacting with the OPNSense's bindservice API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/dns/bind/src/opnsense/mvc/app/models/OPNsense/Bind/General.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def dnsbl(self, args={}, params={}):
        """"""
        url = "bind/service/dnsbl/"
        data = {}

        data = self._get( url, args)
        return data

    def reconfigure(self, args={}, params={}):
        """"""
        url = "bind/service/reconfigure/"
        data = {}

        data = self._get( url, args)
        return data

    def restart(self, args={}, params={}):
        """"""
        url = "bind/service/restart/"
        data = {}

        data = self._get( url, args)
        return data

    def start(self, args={}, params={}):
        """"""
        url = "bind/service/start/"
        data = {}

        data = self._get( url, args)
        return data

    def status(self, args={}, params={}):
        """"""
        url = "bind/service/status/"
        data = {}

        data = self._get( url, args)
        return data

    def stop(self, args={}, params={}):
        """"""
        url = "bind/service/stop/"
        data = {}

        data = self._get( url, args)
        return data



#!/bin/python3
# Copyright 2021 by opensource@secinfra.fr
# Initially from Matthew Treinish's https://github.com/mtreinish/pyopnsense
# Improved a bit.

#
# This file is part of pyopnsense2
#
# pyopnsense2 is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# pyopnsense2 is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with pyopnsense2. If not, see <http://www.gnu.org/licenses/>.

from pyopnsense2 import client
from six.moves import urllib
import json

class haproxy_export(client.BaseClient):
    """A client for interacting with the OPNSense's haproxyexport API.
    for more information on used parameters, see : 

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def config(self, args={}, params={}):
        """"""
        url = "haproxy/export/config/"
        data = {}

        data = self._get( url, args)
        return data

    def diff(self, args={}, params={}):
        """"""
        url = "haproxy/export/diff/"
        data = {}

        data = self._get( url, args)
        return data

    def download(self, args={}, params={}):
        """"""
        url = "haproxy/export/download/"
        data = {}

        if "type" not in args.keys():
            return self.log_error("mandatory argument type is missing")
        else:
            url += args.pop("type")+"/"

        data = self._get( url, args)
        return data

class haproxy_maintenance(client.BaseClient):
    """A client for interacting with the OPNSense's haproxymaintenance API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/net/haproxy/src/opnsense/mvc/app/models/OPNsense/HAProxy/HAProxy.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def certActions(self, args={}, params={}):
        """"""
        url = "haproxy/maintenance/certActions/"
        data = {}

        data = self._get( url, args)
        return data

    def certDiff(self, args={}, params={}):
        """"""
        url = "haproxy/maintenance/certDiff/"
        data = {}

        data = self._get( url, args)
        return data

    def certSync(self, args={}, params={}):
        """"""
        url = "haproxy/maintenance/certSync/"
        data = {}

        data = self._get( url, args)
        return data

    def certSyncBulk(self, args={}, params={}):
        """"""
        url = "haproxy/maintenance/certSyncBulk/"
        data = {}

        data = self._get( url, args)
        return data

    def fetchCronIntegration(self, args={}, params={}):
        """"""
        url = "haproxy/maintenance/fetchCronIntegration/"
        data = {}

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "haproxy/maintenance/get/"
        data = {}

        data = self._get( url, args)
        return data

    def searchCertificateDiff(self, args={}, params={}):
        """"""
        url = "haproxy/maintenance/searchCertificateDiff/"
        data = {}

        data = self._get( url, args)
        return data

    def searchServer(self, args={}, params={}):
        """"""
        url = "haproxy/maintenance/searchServer/"
        data = {}

        data = self._get( url, args)
        return data

    def serverState(self, args={}, params={}):
        """"""
        url = "haproxy/maintenance/serverState/"
        data = {}

        data = self._get( url, args)
        return data

    def serverStateBulk(self, args={}, params={}):
        """"""
        url = "haproxy/maintenance/serverStateBulk/"
        data = {}

        data = self._get( url, args)
        return data

    def serverWeight(self, args={}, params={}):
        """"""
        url = "haproxy/maintenance/serverWeight/"
        data = {}

        data = self._get( url, args)
        return data

    def serverWeightBulk(self, args={}, params={}):
        """"""
        url = "haproxy/maintenance/serverWeightBulk/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "haproxy/maintenance/set/"
        data = {}

        data = self._get( url, args)
        return data

class haproxy_service(client.BaseClient):
    """A client for interacting with the OPNSense's haproxyservice API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/net/haproxy/src/opnsense/mvc/app/models/OPNsense/HAProxy/HAProxy.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def configtest(self, args={}, params={}):
        """"""
        url = "haproxy/service/configtest/"
        data = {}

        data = self._get( url, args)
        return data

    def reconfigure(self, args={}, params={}):
        """"""
        url = "haproxy/service/reconfigure/"
        data = {}

        data = self._get( url, args)
        return data

    def restart(self, args={}, params={}):
        """"""
        url = "haproxy/service/restart/"
        data = {}

        data = self._get( url, args)
        return data

    def start(self, args={}, params={}):
        """"""
        url = "haproxy/service/start/"
        data = {}

        data = self._get( url, args)
        return data

    def status(self, args={}, params={}):
        """"""
        url = "haproxy/service/status/"
        data = {}

        data = self._get( url, args)
        return data

    def stop(self, args={}, params={}):
        """"""
        url = "haproxy/service/stop/"
        data = {}

        data = self._get( url, args)
        return data

class haproxy_settings(client.BaseClient):
    """A client for interacting with the OPNSense's haproxysettings API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/net/haproxy/src/opnsense/mvc/app/models/OPNsense/HAProxy/HAProxy.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addAcl(self, args={}, params={}):
        """"""
        url = "haproxy/settings/addAcl/"
        data = {}

        data = self._post( url, args)
        return data

    def addAction(self, args={}, params={}):
        """"""
        url = "haproxy/settings/addAction/"
        data = {}

        data = self._post( url, args)
        return data

    def addBackend(self, args={}, params={}):
        """"""
        url = "haproxy/settings/addBackend/"
        data = {}

        data = self._post( url, args)
        return data

    def addCpu(self, args={}, params={}):
        """"""
        url = "haproxy/settings/addCpu/"
        data = {}

        data = self._post( url, args)
        return data

    def addErrorfile(self, args={}, params={}):
        """"""
        url = "haproxy/settings/addErrorfile/"
        data = {}

        data = self._post( url, args)
        return data

    def addFrontend(self, args={}, params={}):
        """"""
        url = "haproxy/settings/addFrontend/"
        data = {}

        data = self._post( url, args)
        return data

    def addGroup(self, args={}, params={}):
        """"""
        url = "haproxy/settings/addGroup/"
        data = {}

        data = self._post( url, args)
        return data

    def addHealthcheck(self, args={}, params={}):
        """"""
        url = "haproxy/settings/addHealthcheck/"
        data = {}

        data = self._post( url, args)
        return data

    def addLua(self, args={}, params={}):
        """"""
        url = "haproxy/settings/addLua/"
        data = {}

        data = self._post( url, args)
        return data

    def addMapfile(self, args={}, params={}):
        """"""
        url = "haproxy/settings/addMapfile/"
        data = {}

        data = self._post( url, args)
        return data

    def addServer(self, args={}, params={}):
        """"""
        url = "haproxy/settings/addServer/"
        data = {}

        data = self._post( url, args)
        return data

    def addUser(self, args={}, params={}):
        """"""
        url = "haproxy/settings/addUser/"
        data = {}

        data = self._post( url, args)
        return data

    def addmailer(self, args={}, params={}):
        """"""
        url = "haproxy/settings/addmailer/"
        data = {}

        data = self._post( url, args)
        return data

    def addresolver(self, args={}, params={}):
        """"""
        url = "haproxy/settings/addresolver/"
        data = {}

        data = self._post( url, args)
        return data

    def delAcl(self, args={}, params={}):
        """"""
        url = "haproxy/settings/delAcl/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delAction(self, args={}, params={}):
        """"""
        url = "haproxy/settings/delAction/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delBackend(self, args={}, params={}):
        """"""
        url = "haproxy/settings/delBackend/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delCpu(self, args={}, params={}):
        """"""
        url = "haproxy/settings/delCpu/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delErrorfile(self, args={}, params={}):
        """"""
        url = "haproxy/settings/delErrorfile/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delFrontend(self, args={}, params={}):
        """"""
        url = "haproxy/settings/delFrontend/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delGroup(self, args={}, params={}):
        """"""
        url = "haproxy/settings/delGroup/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delHealthcheck(self, args={}, params={}):
        """"""
        url = "haproxy/settings/delHealthcheck/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delLua(self, args={}, params={}):
        """"""
        url = "haproxy/settings/delLua/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delMapfile(self, args={}, params={}):
        """"""
        url = "haproxy/settings/delMapfile/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delServer(self, args={}, params={}):
        """"""
        url = "haproxy/settings/delServer/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delUser(self, args={}, params={}):
        """"""
        url = "haproxy/settings/delUser/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delmailer(self, args={}, params={}):
        """"""
        url = "haproxy/settings/delmailer/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delresolver(self, args={}, params={}):
        """"""
        url = "haproxy/settings/delresolver/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "haproxy/settings/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getAcl(self, args={}, params={}):
        """"""
        url = "haproxy/settings/getAcl/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getAction(self, args={}, params={}):
        """"""
        url = "haproxy/settings/getAction/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getBackend(self, args={}, params={}):
        """"""
        url = "haproxy/settings/getBackend/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getCpu(self, args={}, params={}):
        """"""
        url = "haproxy/settings/getCpu/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getErrorfile(self, args={}, params={}):
        """"""
        url = "haproxy/settings/getErrorfile/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getFrontend(self, args={}, params={}):
        """"""
        url = "haproxy/settings/getFrontend/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getGroup(self, args={}, params={}):
        """"""
        url = "haproxy/settings/getGroup/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getHealthcheck(self, args={}, params={}):
        """"""
        url = "haproxy/settings/getHealthcheck/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getLua(self, args={}, params={}):
        """"""
        url = "haproxy/settings/getLua/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getMapfile(self, args={}, params={}):
        """"""
        url = "haproxy/settings/getMapfile/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getServer(self, args={}, params={}):
        """"""
        url = "haproxy/settings/getServer/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getUser(self, args={}, params={}):
        """"""
        url = "haproxy/settings/getUser/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getmailer(self, args={}, params={}):
        """"""
        url = "haproxy/settings/getmailer/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getresolver(self, args={}, params={}):
        """"""
        url = "haproxy/settings/getresolver/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchAcls(self, args={}, params={}):
        """"""
        url = "haproxy/settings/searchAcls/"
        data = {}

        data = self._get( url, args)
        return data

    def searchActions(self, args={}, params={}):
        """"""
        url = "haproxy/settings/searchActions/"
        data = {}

        data = self._get( url, args)
        return data

    def searchBackends(self, args={}, params={}):
        """"""
        url = "haproxy/settings/searchBackends/"
        data = {}

        data = self._get( url, args)
        return data

    def searchCpus(self, args={}, params={}):
        """"""
        url = "haproxy/settings/searchCpus/"
        data = {}

        data = self._get( url, args)
        return data

    def searchErrorfiles(self, args={}, params={}):
        """"""
        url = "haproxy/settings/searchErrorfiles/"
        data = {}

        data = self._get( url, args)
        return data

    def searchFrontends(self, args={}, params={}):
        """"""
        url = "haproxy/settings/searchFrontends/"
        data = {}

        data = self._get( url, args)
        return data

    def searchGroups(self, args={}, params={}):
        """"""
        url = "haproxy/settings/searchGroups/"
        data = {}

        data = self._get( url, args)
        return data

    def searchHealthchecks(self, args={}, params={}):
        """"""
        url = "haproxy/settings/searchHealthchecks/"
        data = {}

        data = self._get( url, args)
        return data

    def searchLuas(self, args={}, params={}):
        """"""
        url = "haproxy/settings/searchLuas/"
        data = {}

        data = self._get( url, args)
        return data

    def searchMapfiles(self, args={}, params={}):
        """"""
        url = "haproxy/settings/searchMapfiles/"
        data = {}

        data = self._get( url, args)
        return data

    def searchServers(self, args={}, params={}):
        """"""
        url = "haproxy/settings/searchServers/"
        data = {}

        data = self._get( url, args)
        return data

    def searchUsers(self, args={}, params={}):
        """"""
        url = "haproxy/settings/searchUsers/"
        data = {}

        data = self._get( url, args)
        return data

    def searchmailers(self, args={}, params={}):
        """"""
        url = "haproxy/settings/searchmailers/"
        data = {}

        data = self._get( url, args)
        return data

    def searchresolvers(self, args={}, params={}):
        """"""
        url = "haproxy/settings/searchresolvers/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "haproxy/settings/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setAcl(self, args={}, params={}):
        """"""
        url = "haproxy/settings/setAcl/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setAction(self, args={}, params={}):
        """"""
        url = "haproxy/settings/setAction/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setBackend(self, args={}, params={}):
        """"""
        url = "haproxy/settings/setBackend/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setCpu(self, args={}, params={}):
        """"""
        url = "haproxy/settings/setCpu/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setErrorfile(self, args={}, params={}):
        """"""
        url = "haproxy/settings/setErrorfile/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setFrontend(self, args={}, params={}):
        """"""
        url = "haproxy/settings/setFrontend/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setGroup(self, args={}, params={}):
        """"""
        url = "haproxy/settings/setGroup/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setHealthcheck(self, args={}, params={}):
        """"""
        url = "haproxy/settings/setHealthcheck/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setLua(self, args={}, params={}):
        """"""
        url = "haproxy/settings/setLua/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setMapfile(self, args={}, params={}):
        """"""
        url = "haproxy/settings/setMapfile/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setServer(self, args={}, params={}):
        """"""
        url = "haproxy/settings/setServer/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setUser(self, args={}, params={}):
        """"""
        url = "haproxy/settings/setUser/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setmailer(self, args={}, params={}):
        """"""
        url = "haproxy/settings/setmailer/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setresolver(self, args={}, params={}):
        """"""
        url = "haproxy/settings/setresolver/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleBackend(self, args={}, params={}):
        """"""
        url = "haproxy/settings/toggleBackend/"
        data = {}

        if "enabled" not in args.keys():
            return self.log_error("mandatory argument enabled is missing")
        else:
            url += args.pop("enabled")+"/"

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleCpu(self, args={}, params={}):
        """"""
        url = "haproxy/settings/toggleCpu/"
        data = {}

        if "enabled" not in args.keys():
            return self.log_error("mandatory argument enabled is missing")
        else:
            url += args.pop("enabled")+"/"

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleFrontend(self, args={}, params={}):
        """"""
        url = "haproxy/settings/toggleFrontend/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleGroup(self, args={}, params={}):
        """"""
        url = "haproxy/settings/toggleGroup/"
        data = {}

        if "enabled" not in args.keys():
            return self.log_error("mandatory argument enabled is missing")
        else:
            url += args.pop("enabled")+"/"

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleLua(self, args={}, params={}):
        """"""
        url = "haproxy/settings/toggleLua/"
        data = {}

        if "enabled" not in args.keys():
            return self.log_error("mandatory argument enabled is missing")
        else:
            url += args.pop("enabled")+"/"

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleServer(self, args={}, params={}):
        """"""
        url = "haproxy/settings/toggleServer/"
        data = {}

        if "enabled" not in args.keys():
            return self.log_error("mandatory argument enabled is missing")
        else:
            url += args.pop("enabled")+"/"

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleUser(self, args={}, params={}):
        """"""
        url = "haproxy/settings/toggleUser/"
        data = {}

        if "enabled" not in args.keys():
            return self.log_error("mandatory argument enabled is missing")
        else:
            url += args.pop("enabled")+"/"

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def togglemailer(self, args={}, params={}):
        """"""
        url = "haproxy/settings/togglemailer/"
        data = {}

        if "enabled" not in args.keys():
            return self.log_error("mandatory argument enabled is missing")
        else:
            url += args.pop("enabled")+"/"

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleresolver(self, args={}, params={}):
        """"""
        url = "haproxy/settings/toggleresolver/"
        data = {}

        if "enabled" not in args.keys():
            return self.log_error("mandatory argument enabled is missing")
        else:
            url += args.pop("enabled")+"/"

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

class haproxy_statistics(client.BaseClient):
    """A client for interacting with the OPNSense's haproxystatistics API.
    for more information on used parameters, see : 

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def counters(self, args={}, params={}):
        """"""
        url = "haproxy/statistics/counters/"
        data = {}

        data = self._get( url, args)
        return data

    def info(self, args={}, params={}):
        """"""
        url = "haproxy/statistics/info/"
        data = {}

        data = self._get( url, args)
        return data

    def tables(self, args={}, params={}):
        """"""
        url = "haproxy/statistics/tables/"
        data = {}

        data = self._get( url, args)
        return data



#!/bin/python3
# Copyright 2021 by opensource@secinfra.fr
# Initially from Matthew Treinish's https://github.com/mtreinish/pyopnsense
# Improved a bit.

#
# This file is part of pyopnsense2
#
# pyopnsense2 is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# pyopnsense2 is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with pyopnsense2. If not, see <http://www.gnu.org/licenses/>.

from pyopnsense2 import client
from six.moves import urllib
import json

class monit_service(client.BaseClient):
    """A client for interacting with the OPNSense's monitservice API.
    for more information on used parameters, see : ['https://github.com/opnsense/core/blob/master/src/opnsense/mvc/app/models/OPNsense/Monit/Monit.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def configtest(self, args={}, params={}):
        """"""
        url = "monit/service/configtest/"
        data = {}

        data = self._post( url, args)
        return data

    def reconfigure(self, args={}, params={}):
        """"""
        url = "monit/service/reconfigure/"
        data = {}

        data = self._get( url, args)
        return data

    def restart(self, args={}, params={}):
        """"""
        url = "monit/service/restart/"
        data = {}

        data = self._get( url, args)
        return data

    def start(self, args={}, params={}):
        """"""
        url = "monit/service/start/"
        data = {}

        data = self._get( url, args)
        return data

    def status(self, args={}, params={}):
        """"""
        url = "monit/service/status/"
        data = {}

        data = self._get( url, args)
        return data

    def stop(self, args={}, params={}):
        """"""
        url = "monit/service/stop/"
        data = {}

        data = self._get( url, args)
        return data

class monit_settings(client.BaseClient):
    """A client for interacting with the OPNSense's monitsettings API.
    for more information on used parameters, see : ['https://github.com/opnsense/core/blob/master/src/opnsense/mvc/app/models/OPNsense/Monit/Monit.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addAlert(self, args={}, params={}):
        """"""
        url = "monit/settings/addAlert/"
        data = {}

        data = self._post( url, args)
        return data

    def addService(self, args={}, params={}):
        """"""
        url = "monit/settings/addService/"
        data = {}

        data = self._post( url, args)
        return data

    def addTest(self, args={}, params={}):
        """"""
        url = "monit/settings/addTest/"
        data = {}

        data = self._post( url, args)
        return data

    def delAlert(self, args={}, params={}):
        """"""
        url = "monit/settings/delAlert/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delService(self, args={}, params={}):
        """"""
        url = "monit/settings/delService/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delTest(self, args={}, params={}):
        """"""
        url = "monit/settings/delTest/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def dirty(self, args={}, params={}):
        """"""
        url = "monit/settings/dirty/"
        data = {}

        data = self._get( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "monit/settings/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getAlert(self, args={}, params={}):
        """"""
        url = "monit/settings/getAlert/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getGeneral(self, args={}, params={}):
        """"""
        url = "monit/settings/getGeneral/"
        data = {}

        data = self._get( url, args)
        return data

    def getService(self, args={}, params={}):
        """"""
        url = "monit/settings/getService/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getTest(self, args={}, params={}):
        """"""
        url = "monit/settings/getTest/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchAlert(self, args={}, params={}):
        """"""
        url = "monit/settings/searchAlert/"
        data = {}

        data = self._get( url, args)
        return data

    def searchService(self, args={}, params={}):
        """"""
        url = "monit/settings/searchService/"
        data = {}

        data = self._get( url, args)
        return data

    def searchTest(self, args={}, params={}):
        """"""
        url = "monit/settings/searchTest/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "monit/settings/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setAlert(self, args={}, params={}):
        """"""
        url = "monit/settings/setAlert/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setService(self, args={}, params={}):
        """"""
        url = "monit/settings/setService/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setTest(self, args={}, params={}):
        """"""
        url = "monit/settings/setTest/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleAlert(self, args={}, params={}):
        """"""
        url = "monit/settings/toggleAlert/"
        data = {}

        if "enabled" not in args.keys():
            return self.log_error("mandatory argument enabled is missing")
        else:
            url += args.pop("enabled")+"/"

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleService(self, args={}, params={}):
        """"""
        url = "monit/settings/toggleService/"
        data = {}

        if "enabled" not in args.keys():
            return self.log_error("mandatory argument enabled is missing")
        else:
            url += args.pop("enabled")+"/"

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

class monit_status(client.BaseClient):
    """A client for interacting with the OPNSense's monitstatus API.
    for more information on used parameters, see : 

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def get(self, args={}, params={}):
        """"""
        url = "monit/status/get/"
        data = {}

        if "format" not in args.keys():
            return self.log_error("mandatory argument format is missing")
        else:
            url += args.pop("format")+"/"

        data = self._get( url, args)
        return data



# Copyright 2021 by opensource@secinfra.fr
# Initially from Matthew Treinish's https://github.com/mtreinish/pyopnsense
# Improved a bit.


import json

import requests
from requests.auth import HTTPDigestAuth

from pyopnsense2 import exceptions

DEFAULT_TIMEOUT = 5

# All the successful HTTP status codes from RFC 7231 & 4918
HTTP_SUCCESS = (200, 201, 202, 203, 204, 205, 206, 207)


class BaseClient(object):
    """Representation of the OPNsense API client."""

    def __init__(self, params={}):
        """Initialize the OPNsense API client."""
        self.params = params

    def log_error(self, msg):
        return { "error" : "[x] %s" % msg }

    def _process_response(self, response):
        """Handle the response."""
        if response.status_code in HTTP_SUCCESS:
            try:
                result = json.loads(response.text)
            except Exception as e:
                result = {'exception':str(e)}
        else:
            result = {'error': {
                "status_code": response.status_code, 
                "resp_body":response.text
            }}
        return result

    def format_url(self, endpoint):
        return '{}/{}'.format(self.params['base_url'], endpoint)

    def _get(self, endpoint, body="NO USE"):
        req_url = self.format_url(endpoint)
        response = requests.get(req_url, verify=self.params['verify_cert'],
                                auth=self.params['auth'],
                                timeout=self.params['timeout'])
        return self._process_response(response)

    def _post(self, endpoint, body):
        req_url = self.format_url(endpoint)
        response = requests.post(req_url, json=body,
                                 verify=self.params['verify_cert'],
                                 auth=self.params['auth'],
                                 timeout=self.params['timeout'])
        return self._process_response(response)



#!/bin/python3
# Copyright 2021 by opensource@secinfra.fr
# Initially from Matthew Treinish's https://github.com/mtreinish/pyopnsense
# Improved a bit.

#
# This file is part of pyopnsense2
#
# pyopnsense2 is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# pyopnsense2 is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with pyopnsense2. If not, see <http://www.gnu.org/licenses/>.

from pyopnsense2 import client
from six.moves import urllib
import json

class proxysso_service(client.BaseClient):
    """A client for interacting with the OPNSense's proxyssoservice API.
    for more information on used parameters, see : 

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def createkeytab(self, args={}, params={}):
        """"""
        url = "proxysso/service/createkeytab/"
        data = {}

        data = self._post( url, args)
        return data

    def deletekeytab(self, args={}, params={}):
        """"""
        url = "proxysso/service/deletekeytab/"
        data = {}

        data = self._get( url, args)
        return data

    def getCheckList(self, args={}, params={}):
        """"""
        url = "proxysso/service/getCheckList/"
        data = {}

        data = self._get( url, args)
        return data

    def showkeytab(self, args={}, params={}):
        """"""
        url = "proxysso/service/showkeytab/"
        data = {}

        data = self._get( url, args)
        return data

    def testkerblogin(self, args={}, params={}):
        """"""
        url = "proxysso/service/testkerblogin/"
        data = {}

        data = self._post( url, args)
        return data

class proxysso_settings(client.BaseClient):
    """A client for interacting with the OPNSense's proxyssosettings API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/www/web-proxy-sso/src/opnsense/mvc/app/models/OPNsense/ProxySSO/ProxySSO.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def get(self, args={}, params={}):
        """"""
        url = "proxysso/settings/get/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "proxysso/settings/set/"
        data = {}

        data = self._get( url, args)
        return data



#!/bin/python3
# Copyright 2021 by opensource@secinfra.fr
# Initially from Matthew Treinish's https://github.com/mtreinish/pyopnsense
# Improved a bit.

#
# This file is part of pyopnsense2
#
# pyopnsense2 is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# pyopnsense2 is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with pyopnsense2. If not, see <http://www.gnu.org/licenses/>.

from pyopnsense2 import client
from six.moves import urllib
import json

class acmeclient_accounts(client.BaseClient):
    """A client for interacting with the OPNSense's acmeclientaccounts API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/security/acme-client/src/opnsense/mvc/app/models/OPNsense/AcmeClient/AcmeClient.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def add(self, args={}, params={}):
        """"""
        url = "acmeclient/accounts/add/"
        data = {}

        data = self._post( url, args)
        return data

    def del(self, args={}, params={}):
        """"""
        url = "acmeclient/accounts/del/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "acmeclient/accounts/get/"
        data = {}

        data = self._get( url, args)
        return data

    def register(self, args={}, params={}):
        """"""
        url = "acmeclient/accounts/register/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def search(self, args={}, params={}):
        """"""
        url = "acmeclient/accounts/search/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "acmeclient/accounts/set/"
        data = {}

        data = self._get( url, args)
        return data

    def toggle(self, args={}, params={}):
        """"""
        url = "acmeclient/accounts/toggle/"
        data = {}

        if "enabled" not in args.keys():
            return self.log_error("mandatory argument enabled is missing")
        else:
            url += args.pop("enabled")+"/"

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def update(self, args={}, params={}):
        """"""
        url = "acmeclient/accounts/update/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

class acmeclient_actions(client.BaseClient):
    """A client for interacting with the OPNSense's acmeclientactions API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/security/acme-client/src/opnsense/mvc/app/models/OPNsense/AcmeClient/AcmeClient.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def add(self, args={}, params={}):
        """"""
        url = "acmeclient/actions/add/"
        data = {}

        data = self._post( url, args)
        return data

    def del(self, args={}, params={}):
        """"""
        url = "acmeclient/actions/del/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "acmeclient/actions/get/"
        data = {}

        data = self._get( url, args)
        return data

    def search(self, args={}, params={}):
        """"""
        url = "acmeclient/actions/search/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "acmeclient/actions/set/"
        data = {}

        data = self._get( url, args)
        return data

    def sftpGetIdentity(self, args={}, params={}):
        """"""
        url = "acmeclient/actions/sftpGetIdentity/"
        data = {}

        data = self._get( url, args)
        return data

    def sftpTestConnection(self, args={}, params={}):
        """"""
        url = "acmeclient/actions/sftpTestConnection/"
        data = {}

        data = self._get( url, args)
        return data

    def toggle(self, args={}, params={}):
        """"""
        url = "acmeclient/actions/toggle/"
        data = {}

        if "enabled" not in args.keys():
            return self.log_error("mandatory argument enabled is missing")
        else:
            url += args.pop("enabled")+"/"

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def update(self, args={}, params={}):
        """"""
        url = "acmeclient/actions/update/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

class acmeclient_certificates(client.BaseClient):
    """A client for interacting with the OPNSense's acmeclientcertificates API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/security/acme-client/src/opnsense/mvc/app/models/OPNsense/AcmeClient/AcmeClient.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def add(self, args={}, params={}):
        """"""
        url = "acmeclient/certificates/add/"
        data = {}

        data = self._post( url, args)
        return data

    def automation(self, args={}, params={}):
        """"""
        url = "acmeclient/certificates/automation/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def del(self, args={}, params={}):
        """"""
        url = "acmeclient/certificates/del/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "acmeclient/certificates/get/"
        data = {}

        data = self._get( url, args)
        return data

    def removekey(self, args={}, params={}):
        """"""
        url = "acmeclient/certificates/removekey/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def revoke(self, args={}, params={}):
        """"""
        url = "acmeclient/certificates/revoke/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def search(self, args={}, params={}):
        """"""
        url = "acmeclient/certificates/search/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "acmeclient/certificates/set/"
        data = {}

        data = self._get( url, args)
        return data

    def sign(self, args={}, params={}):
        """"""
        url = "acmeclient/certificates/sign/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggle(self, args={}, params={}):
        """"""
        url = "acmeclient/certificates/toggle/"
        data = {}

        if "enabled" not in args.keys():
            return self.log_error("mandatory argument enabled is missing")
        else:
            url += args.pop("enabled")+"/"

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def update(self, args={}, params={}):
        """"""
        url = "acmeclient/certificates/update/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

class acmeclient_service(client.BaseClient):
    """A client for interacting with the OPNSense's acmeclientservice API.
    for more information on used parameters, see : 

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def configtest(self, args={}, params={}):
        """"""
        url = "acmeclient/service/configtest/"
        data = {}

        data = self._get( url, args)
        return data

    def reconfigure(self, args={}, params={}):
        """"""
        url = "acmeclient/service/reconfigure/"
        data = {}

        data = self._post( url, args)
        return data

    def reset(self, args={}, params={}):
        """"""
        url = "acmeclient/service/reset/"
        data = {}

        data = self._get( url, args)
        return data

    def restart(self, args={}, params={}):
        """"""
        url = "acmeclient/service/restart/"
        data = {}

        data = self._post( url, args)
        return data

    def signallcerts(self, args={}, params={}):
        """"""
        url = "acmeclient/service/signallcerts/"
        data = {}

        data = self._get( url, args)
        return data

    def start(self, args={}, params={}):
        """"""
        url = "acmeclient/service/start/"
        data = {}

        data = self._post( url, args)
        return data

    def status(self, args={}, params={}):
        """"""
        url = "acmeclient/service/status/"
        data = {}

        data = self._get( url, args)
        return data

    def stop(self, args={}, params={}):
        """"""
        url = "acmeclient/service/stop/"
        data = {}

        data = self._post( url, args)
        return data

class acmeclient_settings(client.BaseClient):
    """A client for interacting with the OPNSense's acmeclientsettings API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/security/acme-client/src/opnsense/mvc/app/models/OPNsense/AcmeClient/AcmeClient.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def fetchCronIntegration(self, args={}, params={}):
        """"""
        url = "acmeclient/settings/fetchCronIntegration/"
        data = {}

        data = self._post( url, args)
        return data

    def fetchHAProxyIntegration(self, args={}, params={}):
        """"""
        url = "acmeclient/settings/fetchHAProxyIntegration/"
        data = {}

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "acmeclient/settings/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getBindPluginStatus(self, args={}, params={}):
        """"""
        url = "acmeclient/settings/getBindPluginStatus/"
        data = {}

        data = self._get( url, args)
        return data

    def getGcloudPluginStatus(self, args={}, params={}):
        """"""
        url = "acmeclient/settings/getGcloudPluginStatus/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "acmeclient/settings/set/"
        data = {}

        data = self._get( url, args)
        return data

class acmeclient_validations(client.BaseClient):
    """A client for interacting with the OPNSense's acmeclientvalidations API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/security/acme-client/src/opnsense/mvc/app/models/OPNsense/AcmeClient/AcmeClient.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def add(self, args={}, params={}):
        """"""
        url = "acmeclient/validations/add/"
        data = {}

        data = self._post( url, args)
        return data

    def del(self, args={}, params={}):
        """"""
        url = "acmeclient/validations/del/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "acmeclient/validations/get/"
        data = {}

        data = self._get( url, args)
        return data

    def search(self, args={}, params={}):
        """"""
        url = "acmeclient/validations/search/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "acmeclient/validations/set/"
        data = {}

        data = self._get( url, args)
        return data

    def toggle(self, args={}, params={}):
        """"""
        url = "acmeclient/validations/toggle/"
        data = {}

        if "enabled" not in args.keys():
            return self.log_error("mandatory argument enabled is missing")
        else:
            url += args.pop("enabled")+"/"

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def update(self, args={}, params={}):
        """"""
        url = "acmeclient/validations/update/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data



#!/bin/python3
# Copyright 2021 by opensource@secinfra.fr
# Initially from Matthew Treinish's https://github.com/mtreinish/pyopnsense
# Improved a bit.

#
# This file is part of pyopnsense2
#
# pyopnsense2 is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# pyopnsense2 is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with pyopnsense2. If not, see <http://www.gnu.org/licenses/>.

from pyopnsense2 import client
from six.moves import urllib
import json

class quagga_bgp(client.BaseClient):
    """A client for interacting with the OPNSense's quaggabgp API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/net/frr/src/opnsense/mvc/app/models/OPNsense/Quagga/BGP.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addAspath(self, args={}, params={}):
        """"""
        url = "quagga/bgp/addAspath/"
        data = {}

        data = self._post( url, args)
        return data

    def addCommunitylist(self, args={}, params={}):
        """"""
        url = "quagga/bgp/addCommunitylist/"
        data = {}

        data = self._post( url, args)
        return data

    def addNeighbor(self, args={}, params={}):
        """"""
        url = "quagga/bgp/addNeighbor/"
        data = {}

        data = self._post( url, args)
        return data

    def addPrefixlist(self, args={}, params={}):
        """"""
        url = "quagga/bgp/addPrefixlist/"
        data = {}

        data = self._post( url, args)
        return data

    def addRoutemap(self, args={}, params={}):
        """"""
        url = "quagga/bgp/addRoutemap/"
        data = {}

        data = self._post( url, args)
        return data

    def delAspath(self, args={}, params={}):
        """"""
        url = "quagga/bgp/delAspath/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delCommunitylist(self, args={}, params={}):
        """"""
        url = "quagga/bgp/delCommunitylist/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delNeighbor(self, args={}, params={}):
        """"""
        url = "quagga/bgp/delNeighbor/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delPrefixlist(self, args={}, params={}):
        """"""
        url = "quagga/bgp/delPrefixlist/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delRoutemap(self, args={}, params={}):
        """"""
        url = "quagga/bgp/delRoutemap/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "quagga/bgp/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getAspath(self, args={}, params={}):
        """"""
        url = "quagga/bgp/getAspath/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getCommunitylist(self, args={}, params={}):
        """"""
        url = "quagga/bgp/getCommunitylist/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getNeighbor(self, args={}, params={}):
        """"""
        url = "quagga/bgp/getNeighbor/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getPrefixlist(self, args={}, params={}):
        """"""
        url = "quagga/bgp/getPrefixlist/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getRoutemap(self, args={}, params={}):
        """"""
        url = "quagga/bgp/getRoutemap/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchAspath(self, args={}, params={}):
        """"""
        url = "quagga/bgp/searchAspath/"
        data = {}

        data = self._get( url, args)
        return data

    def searchCommunitylist(self, args={}, params={}):
        """"""
        url = "quagga/bgp/searchCommunitylist/"
        data = {}

        data = self._get( url, args)
        return data

    def searchNeighbor(self, args={}, params={}):
        """"""
        url = "quagga/bgp/searchNeighbor/"
        data = {}

        data = self._get( url, args)
        return data

    def searchPrefixlist(self, args={}, params={}):
        """"""
        url = "quagga/bgp/searchPrefixlist/"
        data = {}

        data = self._get( url, args)
        return data

    def searchRoutemap(self, args={}, params={}):
        """"""
        url = "quagga/bgp/searchRoutemap/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "quagga/bgp/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setAspath(self, args={}, params={}):
        """"""
        url = "quagga/bgp/setAspath/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setCommunitylist(self, args={}, params={}):
        """"""
        url = "quagga/bgp/setCommunitylist/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setNeighbor(self, args={}, params={}):
        """"""
        url = "quagga/bgp/setNeighbor/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setPrefixlist(self, args={}, params={}):
        """"""
        url = "quagga/bgp/setPrefixlist/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setRoutemap(self, args={}, params={}):
        """"""
        url = "quagga/bgp/setRoutemap/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleAspath(self, args={}, params={}):
        """"""
        url = "quagga/bgp/toggleAspath/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleNeighbor(self, args={}, params={}):
        """"""
        url = "quagga/bgp/toggleNeighbor/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def togglePrefixlist(self, args={}, params={}):
        """"""
        url = "quagga/bgp/togglePrefixlist/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleRoutemap(self, args={}, params={}):
        """"""
        url = "quagga/bgp/toggleRoutemap/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

class quagga_diagnostics(client.BaseClient):
    """A client for interacting with the OPNSense's quaggadiagnostics API.
    for more information on used parameters, see : 

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def bgpneighbors(self, args={}, params={}):
        """"""
        url = "quagga/diagnostics/bgpneighbors/"
        data = {}

        if "format" not in args.keys():
            return self.log_error("mandatory argument format is missing")
        else:
            url += args.pop("format")+"/"

        data = self._get( url, args)
        return data

    def bgproute(self, args={}, params={}):
        """"""
        url = "quagga/diagnostics/bgproute/"
        data = {}

        if "format" not in args.keys():
            return self.log_error("mandatory argument format is missing")
        else:
            url += args.pop("format")+"/"

        data = self._get( url, args)
        return data

    def bgproute4(self, args={}, params={}):
        """"""
        url = "quagga/diagnostics/bgproute4/"
        data = {}

        if "format" not in args.keys():
            return self.log_error("mandatory argument format is missing")
        else:
            url += args.pop("format")+"/"

        data = self._get( url, args)
        return data

    def bgproute6(self, args={}, params={}):
        """"""
        url = "quagga/diagnostics/bgproute6/"
        data = {}

        if "format" not in args.keys():
            return self.log_error("mandatory argument format is missing")
        else:
            url += args.pop("format")+"/"

        data = self._get( url, args)
        return data

    def bgpsummary(self, args={}, params={}):
        """"""
        url = "quagga/diagnostics/bgpsummary/"
        data = {}

        if "format" not in args.keys():
            return self.log_error("mandatory argument format is missing")
        else:
            url += args.pop("format")+"/"

        data = self._get( url, args)
        return data

    def generalroute(self, args={}, params={}):
        """"""
        url = "quagga/diagnostics/generalroute/"
        data = {}

        if "format" not in args.keys():
            return self.log_error("mandatory argument format is missing")
        else:
            url += args.pop("format")+"/"

        data = self._get( url, args)
        return data

    def generalroute4(self, args={}, params={}):
        """"""
        url = "quagga/diagnostics/generalroute4/"
        data = {}

        if "format" not in args.keys():
            return self.log_error("mandatory argument format is missing")
        else:
            url += args.pop("format")+"/"

        data = self._get( url, args)
        return data

    def generalroute6(self, args={}, params={}):
        """"""
        url = "quagga/diagnostics/generalroute6/"
        data = {}

        if "format" not in args.keys():
            return self.log_error("mandatory argument format is missing")
        else:
            url += args.pop("format")+"/"

        data = self._get( url, args)
        return data

    def generalrunningconfig(self, args={}, params={}):
        """"""
        url = "quagga/diagnostics/generalrunningconfig/"
        data = {}

        data = self._get( url, args)
        return data

    def ospfdatabase(self, args={}, params={}):
        """"""
        url = "quagga/diagnostics/ospfdatabase/"
        data = {}

        if "format" not in args.keys():
            return self.log_error("mandatory argument format is missing")
        else:
            url += args.pop("format")+"/"

        data = self._get( url, args)
        return data

    def ospfinterface(self, args={}, params={}):
        """"""
        url = "quagga/diagnostics/ospfinterface/"
        data = {}

        if "format" not in args.keys():
            return self.log_error("mandatory argument format is missing")
        else:
            url += args.pop("format")+"/"

        data = self._get( url, args)
        return data

    def ospfneighbor(self, args={}, params={}):
        """"""
        url = "quagga/diagnostics/ospfneighbor/"
        data = {}

        if "format" not in args.keys():
            return self.log_error("mandatory argument format is missing")
        else:
            url += args.pop("format")+"/"

        data = self._get( url, args)
        return data

    def ospfoverview(self, args={}, params={}):
        """"""
        url = "quagga/diagnostics/ospfoverview/"
        data = {}

        if "format" not in args.keys():
            return self.log_error("mandatory argument format is missing")
        else:
            url += args.pop("format")+"/"

        data = self._get( url, args)
        return data

    def ospfroute(self, args={}, params={}):
        """"""
        url = "quagga/diagnostics/ospfroute/"
        data = {}

        if "format" not in args.keys():
            return self.log_error("mandatory argument format is missing")
        else:
            url += args.pop("format")+"/"

        data = self._get( url, args)
        return data

    def ospfv3database(self, args={}, params={}):
        """"""
        url = "quagga/diagnostics/ospfv3database/"
        data = {}

        if "format" not in args.keys():
            return self.log_error("mandatory argument format is missing")
        else:
            url += args.pop("format")+"/"

        data = self._get( url, args)
        return data

    def ospfv3interface(self, args={}, params={}):
        """"""
        url = "quagga/diagnostics/ospfv3interface/"
        data = {}

        if "format" not in args.keys():
            return self.log_error("mandatory argument format is missing")
        else:
            url += args.pop("format")+"/"

        data = self._get( url, args)
        return data

    def ospfv3neighbor(self, args={}, params={}):
        """"""
        url = "quagga/diagnostics/ospfv3neighbor/"
        data = {}

        if "format" not in args.keys():
            return self.log_error("mandatory argument format is missing")
        else:
            url += args.pop("format")+"/"

        data = self._get( url, args)
        return data

    def ospfv3overview(self, args={}, params={}):
        """"""
        url = "quagga/diagnostics/ospfv3overview/"
        data = {}

        if "format" not in args.keys():
            return self.log_error("mandatory argument format is missing")
        else:
            url += args.pop("format")+"/"

        data = self._get( url, args)
        return data

    def ospfv3route(self, args={}, params={}):
        """"""
        url = "quagga/diagnostics/ospfv3route/"
        data = {}

        if "format" not in args.keys():
            return self.log_error("mandatory argument format is missing")
        else:
            url += args.pop("format")+"/"

        data = self._get( url, args)
        return data

class quagga_general(client.BaseClient):
    """A client for interacting with the OPNSense's quaggageneral API.
    for more information on used parameters, see : 

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def get(self, args={}, params={}):
        """"""
        url = "quagga/general/get/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "quagga/general/set/"
        data = {}

        data = self._post( url, args)
        return data

class quagga_ospf6settings(client.BaseClient):
    """A client for interacting with the OPNSense's quaggaospf6settings API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/net/frr/src/opnsense/mvc/app/models/OPNsense/Quagga/OSPF6.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addInterface(self, args={}, params={}):
        """"""
        url = "quagga/ospf6settings/addInterface/"
        data = {}

        data = self._post( url, args)
        return data

    def delInterface(self, args={}, params={}):
        """"""
        url = "quagga/ospf6settings/delInterface/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "quagga/ospf6settings/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getInterface(self, args={}, params={}):
        """"""
        url = "quagga/ospf6settings/getInterface/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchInterface(self, args={}, params={}):
        """"""
        url = "quagga/ospf6settings/searchInterface/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "quagga/ospf6settings/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setInterface(self, args={}, params={}):
        """"""
        url = "quagga/ospf6settings/setInterface/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleInterface(self, args={}, params={}):
        """"""
        url = "quagga/ospf6settings/toggleInterface/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

class quagga_ospfsettings(client.BaseClient):
    """A client for interacting with the OPNSense's quaggaospfsettings API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/net/frr/src/opnsense/mvc/app/models/OPNsense/Quagga/OSPF.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addInterface(self, args={}, params={}):
        """"""
        url = "quagga/ospfsettings/addInterface/"
        data = {}

        data = self._post( url, args)
        return data

    def addNetwork(self, args={}, params={}):
        """"""
        url = "quagga/ospfsettings/addNetwork/"
        data = {}

        data = self._post( url, args)
        return data

    def addPrefixlist(self, args={}, params={}):
        """"""
        url = "quagga/ospfsettings/addPrefixlist/"
        data = {}

        data = self._post( url, args)
        return data

    def addRoutemap(self, args={}, params={}):
        """"""
        url = "quagga/ospfsettings/addRoutemap/"
        data = {}

        data = self._post( url, args)
        return data

    def delInterface(self, args={}, params={}):
        """"""
        url = "quagga/ospfsettings/delInterface/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delNetwork(self, args={}, params={}):
        """"""
        url = "quagga/ospfsettings/delNetwork/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delPrefixlist(self, args={}, params={}):
        """"""
        url = "quagga/ospfsettings/delPrefixlist/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delRoutemap(self, args={}, params={}):
        """"""
        url = "quagga/ospfsettings/delRoutemap/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "quagga/ospfsettings/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getInterface(self, args={}, params={}):
        """"""
        url = "quagga/ospfsettings/getInterface/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getNetwork(self, args={}, params={}):
        """"""
        url = "quagga/ospfsettings/getNetwork/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getPrefixlist(self, args={}, params={}):
        """"""
        url = "quagga/ospfsettings/getPrefixlist/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getRoutemap(self, args={}, params={}):
        """"""
        url = "quagga/ospfsettings/getRoutemap/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchInterface(self, args={}, params={}):
        """"""
        url = "quagga/ospfsettings/searchInterface/"
        data = {}

        data = self._get( url, args)
        return data

    def searchNetwork(self, args={}, params={}):
        """"""
        url = "quagga/ospfsettings/searchNetwork/"
        data = {}

        data = self._get( url, args)
        return data

    def searchPrefixlist(self, args={}, params={}):
        """"""
        url = "quagga/ospfsettings/searchPrefixlist/"
        data = {}

        data = self._get( url, args)
        return data

    def searchRoutemap(self, args={}, params={}):
        """"""
        url = "quagga/ospfsettings/searchRoutemap/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "quagga/ospfsettings/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setInterface(self, args={}, params={}):
        """"""
        url = "quagga/ospfsettings/setInterface/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setNetwork(self, args={}, params={}):
        """"""
        url = "quagga/ospfsettings/setNetwork/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setPrefixlist(self, args={}, params={}):
        """"""
        url = "quagga/ospfsettings/setPrefixlist/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setRoutemap(self, args={}, params={}):
        """"""
        url = "quagga/ospfsettings/setRoutemap/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleInterface(self, args={}, params={}):
        """"""
        url = "quagga/ospfsettings/toggleInterface/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleNetwork(self, args={}, params={}):
        """"""
        url = "quagga/ospfsettings/toggleNetwork/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def togglePrefixlist(self, args={}, params={}):
        """"""
        url = "quagga/ospfsettings/togglePrefixlist/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleRoutemap(self, args={}, params={}):
        """"""
        url = "quagga/ospfsettings/toggleRoutemap/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

class quagga_rip(client.BaseClient):
    """A client for interacting with the OPNSense's quaggarip API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/net/frr/src/opnsense/mvc/app/models/OPNsense/Quagga/RIP.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def get(self, args={}, params={}):
        """"""
        url = "quagga/rip/get/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "quagga/rip/set/"
        data = {}

        data = self._get( url, args)
        return data

class quagga_service(client.BaseClient):
    """A client for interacting with the OPNSense's quaggaservice API.
    for more information on used parameters, see : 

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def reconfigure(self, args={}, params={}):
        """"""
        url = "quagga/service/reconfigure/"
        data = {}

        data = self._post( url, args)
        return data

    def restart(self, args={}, params={}):
        """"""
        url = "quagga/service/restart/"
        data = {}

        data = self._post( url, args)
        return data

    def start(self, args={}, params={}):
        """"""
        url = "quagga/service/start/"
        data = {}

        data = self._post( url, args)
        return data

    def status(self, args={}, params={}):
        """"""
        url = "quagga/service/status/"
        data = {}

        data = self._get( url, args)
        return data

    def stop(self, args={}, params={}):
        """"""
        url = "quagga/service/stop/"
        data = {}

        data = self._post( url, args)
        return data



#!/bin/python3
# Copyright 2021 by opensource@secinfra.fr
# Initially from Matthew Treinish's https://github.com/mtreinish/pyopnsense
# Improved a bit.

#
# This file is part of pyopnsense2
#
# pyopnsense2 is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# pyopnsense2 is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with pyopnsense2. If not, see <http://www.gnu.org/licenses/>.

from pyopnsense2 import client
from six.moves import urllib
import json

class ids_service(client.BaseClient):
    """A client for interacting with the OPNSense's idsservice API.
    for more information on used parameters, see : ['https://github.com/opnsense/core/blob/master/src/opnsense/mvc/app/models/OPNsense/IDS/IDS.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def dropAlertLog(self, args={}, params={}):
        """"""
        url = "ids/service/dropAlertLog/"
        data = {}

        data = self._post( url, args)
        return data

    def getAlertInfo(self, args={}, params={}):
        """"""
        url = "ids/service/getAlertInfo/"
        data = {}

        if "alertId" not in args.keys():
            return self.log_error("mandatory argument alertId is missing")
        else:
            url += args.pop("alertId")+"/"

        if "fileid" not in args.keys():
            return self.log_error("mandatory argument fileid is missing")
        else:
            url += args.pop("fileid")+"/"

        data = self._get( url, args)
        return data

    def getAlertLogs(self, args={}, params={}):
        """"""
        url = "ids/service/getAlertLogs/"
        data = {}

        data = self._get( url, args)
        return data

    def queryAlerts(self, args={}, params={}):
        """"""
        url = "ids/service/queryAlerts/"
        data = {}

        data = self._post( url, args)
        return data

    def reconfigure(self, args={}, params={}):
        """"""
        url = "ids/service/reconfigure/"
        data = {}

        data = self._get( url, args)
        return data

    def reloadRules(self, args={}, params={}):
        """"""
        url = "ids/service/reloadRules/"
        data = {}

        data = self._post( url, args)
        return data

    def restart(self, args={}, params={}):
        """"""
        url = "ids/service/restart/"
        data = {}

        data = self._get( url, args)
        return data

    def start(self, args={}, params={}):
        """"""
        url = "ids/service/start/"
        data = {}

        data = self._get( url, args)
        return data

    def status(self, args={}, params={}):
        """"""
        url = "ids/service/status/"
        data = {}

        data = self._get( url, args)
        return data

    def stop(self, args={}, params={}):
        """"""
        url = "ids/service/stop/"
        data = {}

        data = self._get( url, args)
        return data

    def updateRules(self, args={}, params={}):
        """"""
        url = "ids/service/updateRules/"
        data = {}

        if "wait" not in args.keys():
            return self.log_error("mandatory argument wait is missing")
        else:
            url += args.pop("wait")+"/"

        data = self._post( url, args)
        return data

class ids_settings(client.BaseClient):
    """A client for interacting with the OPNSense's idssettings API.
    for more information on used parameters, see : ['https://github.com/opnsense/core/blob/master/src/opnsense/mvc/app/models/OPNsense/IDS/IDS.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addPolicy(self, args={}, params={}):
        """"""
        url = "ids/settings/addPolicy/"
        data = {}

        data = self._post( url, args)
        return data

    def addPolicyRule(self, args={}, params={}):
        """"""
        url = "ids/settings/addPolicyRule/"
        data = {}

        data = self._post( url, args)
        return data

    def addUserRule(self, args={}, params={}):
        """"""
        url = "ids/settings/addUserRule/"
        data = {}

        data = self._post( url, args)
        return data

    def checkPolicyRule(self, args={}, params={}):
        """"""
        url = "ids/settings/checkPolicyRule/"
        data = {}

        data = self._get( url, args)
        return data

    def delPolicy(self, args={}, params={}):
        """"""
        url = "ids/settings/delPolicy/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delPolicyRule(self, args={}, params={}):
        """"""
        url = "ids/settings/delPolicyRule/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delUserRule(self, args={}, params={}):
        """"""
        url = "ids/settings/delUserRule/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "ids/settings/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getPolicy(self, args={}, params={}):
        """"""
        url = "ids/settings/getPolicy/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getPolicyRule(self, args={}, params={}):
        """"""
        url = "ids/settings/getPolicyRule/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getRuleInfo(self, args={}, params={}):
        """"""
        url = "ids/settings/getRuleInfo/"
        data = {}

        if "sid" not in args.keys():
            return self.log_error("mandatory argument sid is missing")
        else:
            url += args.pop("sid")+"/"

        data = self._get( url, args)
        return data

    def getRuleset(self, args={}, params={}):
        """"""
        url = "ids/settings/getRuleset/"
        data = {}

        if "id" not in args.keys():
            return self.log_error("mandatory argument id is missing")
        else:
            url += args.pop("id")+"/"

        data = self._get( url, args)
        return data

    def getRulesetproperties(self, args={}, params={}):
        """"""
        url = "ids/settings/getRulesetproperties/"
        data = {}

        data = self._get( url, args)
        return data

    def getUserRule(self, args={}, params={}):
        """"""
        url = "ids/settings/getUserRule/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def listRuleMetadata(self, args={}, params={}):
        """"""
        url = "ids/settings/listRuleMetadata/"
        data = {}

        data = self._get( url, args)
        return data

    def listRulesets(self, args={}, params={}):
        """"""
        url = "ids/settings/listRulesets/"
        data = {}

        data = self._get( url, args)
        return data

    def searchInstalledRules(self, args={}, params={}):
        """"""
        url = "ids/settings/searchInstalledRules/"
        data = {}

        data = self._post( url, args)
        return data

    def searchPolicy(self, args={}, params={}):
        """"""
        url = "ids/settings/searchPolicy/"
        data = {}

        data = self._get( url, args)
        return data

    def searchPolicyRule(self, args={}, params={}):
        """"""
        url = "ids/settings/searchPolicyRule/"
        data = {}

        data = self._get( url, args)
        return data

    def searchUserRule(self, args={}, params={}):
        """"""
        url = "ids/settings/searchUserRule/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "ids/settings/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setPolicy(self, args={}, params={}):
        """"""
        url = "ids/settings/setPolicy/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setPolicyRule(self, args={}, params={}):
        """"""
        url = "ids/settings/setPolicyRule/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setRule(self, args={}, params={}):
        """"""
        url = "ids/settings/setRule/"
        data = {}

        if "sid" not in args.keys():
            return self.log_error("mandatory argument sid is missing")
        else:
            url += args.pop("sid")+"/"

        data = self._post( url, args)
        return data

    def setRuleset(self, args={}, params={}):
        """"""
        url = "ids/settings/setRuleset/"
        data = {}

        if "filename" not in args.keys():
            return self.log_error("mandatory argument filename is missing")
        else:
            url += args.pop("filename")+"/"

        data = self._post( url, args)
        return data

    def setRulesetproperties(self, args={}, params={}):
        """"""
        url = "ids/settings/setRulesetproperties/"
        data = {}

        data = self._post( url, args)
        return data

    def setUserRule(self, args={}, params={}):
        """"""
        url = "ids/settings/setUserRule/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def togglePolicy(self, args={}, params={}):
        """"""
        url = "ids/settings/togglePolicy/"
        data = {}

        if "enabled" not in args.keys():
            return self.log_error("mandatory argument enabled is missing")
        else:
            url += args.pop("enabled")+"/"

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def togglePolicyRule(self, args={}, params={}):
        """"""
        url = "ids/settings/togglePolicyRule/"
        data = {}

        if "enabled" not in args.keys():
            return self.log_error("mandatory argument enabled is missing")
        else:
            url += args.pop("enabled")+"/"

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleRule(self, args={}, params={}):
        """"""
        url = "ids/settings/toggleRule/"
        data = {}

        if "enabled" not in args.keys():
            return self.log_error("mandatory argument enabled is missing")
        else:
            url += args.pop("enabled")+"/"

        if "sids" not in args.keys():
            return self.log_error("mandatory argument sids is missing")
        else:
            url += args.pop("sids")+"/"

        data = self._post( url, args)
        return data

    def toggleRuleset(self, args={}, params={}):
        """"""
        url = "ids/settings/toggleRuleset/"
        data = {}

        if "enabled" not in args.keys():
            return self.log_error("mandatory argument enabled is missing")
        else:
            url += args.pop("enabled")+"/"

        if "filenames" not in args.keys():
            return self.log_error("mandatory argument filenames is missing")
        else:
            url += args.pop("filenames")+"/"

        data = self._post( url, args)
        return data

    def toggleUserRule(self, args={}, params={}):
        """"""
        url = "ids/settings/toggleUserRule/"
        data = {}

        if "enabled" not in args.keys():
            return self.log_error("mandatory argument enabled is missing")
        else:
            url += args.pop("enabled")+"/"

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data



#!/bin/python3
# Copyright 2021 by opensource@secinfra.fr
# Initially from Matthew Treinish's https://github.com/mtreinish/pyopnsense
# Improved a bit.

#
# This file is part of pyopnsense2
#
# pyopnsense2 is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# pyopnsense2 is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with pyopnsense2. If not, see <http://www.gnu.org/licenses/>.

from pyopnsense2 import client
from six.moves import urllib
import json

class tor_exitacl(client.BaseClient):
    """A client for interacting with the OPNSense's torexitacl API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/security/tor/src/opnsense/mvc/app/models/OPNsense/Tor/ACLExitPolicy.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addacl(self, args={}, params={}):
        """"""
        url = "tor/exitacl/addacl/"
        data = {}

        data = self._post( url, args)
        return data

    def delacl(self, args={}, params={}):
        """"""
        url = "tor/exitacl/delacl/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "tor/exitacl/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getacl(self, args={}, params={}):
        """"""
        url = "tor/exitacl/getacl/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchacl(self, args={}, params={}):
        """"""
        url = "tor/exitacl/searchacl/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "tor/exitacl/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setacl(self, args={}, params={}):
        """"""
        url = "tor/exitacl/setacl/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleacl(self, args={}, params={}):
        """"""
        url = "tor/exitacl/toggleacl/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

class tor_general(client.BaseClient):
    """A client for interacting with the OPNSense's torgeneral API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/security/tor/src/opnsense/mvc/app/models/OPNsense/Tor/General.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addhidservauth(self, args={}, params={}):
        """"""
        url = "tor/general/addhidservauth/"
        data = {}

        data = self._post( url, args)
        return data

    def delhidservauth(self, args={}, params={}):
        """"""
        url = "tor/general/delhidservauth/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "tor/general/get/"
        data = {}

        data = self._get( url, args)
        return data

    def gethidservauth(self, args={}, params={}):
        """"""
        url = "tor/general/gethidservauth/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchhidservauth(self, args={}, params={}):
        """"""
        url = "tor/general/searchhidservauth/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "tor/general/set/"
        data = {}

        data = self._get( url, args)
        return data

    def sethidservauth(self, args={}, params={}):
        """"""
        url = "tor/general/sethidservauth/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def togglehidservauth(self, args={}, params={}):
        """"""
        url = "tor/general/togglehidservauth/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

class tor_hiddenservice(client.BaseClient):
    """A client for interacting with the OPNSense's torhiddenservice API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/security/tor/src/opnsense/mvc/app/models/OPNsense/Tor/HiddenService.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addservice(self, args={}, params={}):
        """"""
        url = "tor/hiddenservice/addservice/"
        data = {}

        data = self._post( url, args)
        return data

    def delservice(self, args={}, params={}):
        """"""
        url = "tor/hiddenservice/delservice/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "tor/hiddenservice/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getservice(self, args={}, params={}):
        """"""
        url = "tor/hiddenservice/getservice/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchservice(self, args={}, params={}):
        """"""
        url = "tor/hiddenservice/searchservice/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "tor/hiddenservice/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setservice(self, args={}, params={}):
        """"""
        url = "tor/hiddenservice/setservice/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleservice(self, args={}, params={}):
        """"""
        url = "tor/hiddenservice/toggleservice/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

class tor_hiddenserviceacl(client.BaseClient):
    """A client for interacting with the OPNSense's torhiddenserviceacl API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/security/tor/src/opnsense/mvc/app/models/OPNsense/Tor/HiddenServiceACL.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addacl(self, args={}, params={}):
        """"""
        url = "tor/hiddenserviceacl/addacl/"
        data = {}

        data = self._post( url, args)
        return data

    def delacl(self, args={}, params={}):
        """"""
        url = "tor/hiddenserviceacl/delacl/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "tor/hiddenserviceacl/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getacl(self, args={}, params={}):
        """"""
        url = "tor/hiddenserviceacl/getacl/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchacl(self, args={}, params={}):
        """"""
        url = "tor/hiddenserviceacl/searchacl/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "tor/hiddenserviceacl/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setacl(self, args={}, params={}):
        """"""
        url = "tor/hiddenserviceacl/setacl/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleacl(self, args={}, params={}):
        """"""
        url = "tor/hiddenserviceacl/toggleacl/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

class tor_relay(client.BaseClient):
    """A client for interacting with the OPNSense's torrelay API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/security/tor/src/opnsense/mvc/app/models/OPNsense/Tor/Relay.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def get(self, args={}, params={}):
        """"""
        url = "tor/relay/get/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "tor/relay/set/"
        data = {}

        data = self._get( url, args)
        return data

class tor_service(client.BaseClient):
    """A client for interacting with the OPNSense's torservice API.
    for more information on used parameters, see : 

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def circuits(self, args={}, params={}):
        """"""
        url = "tor/service/circuits/"
        data = {}

        data = self._get( url, args)
        return data

    def get_hidden_services(self, args={}, params={}):
        """"""
        url = "tor/service/get_hidden_services/"
        data = {}

        data = self._get( url, args)
        return data

    def reconfigure(self, args={}, params={}):
        """"""
        url = "tor/service/reconfigure/"
        data = {}

        data = self._post( url, args)
        return data

    def restart(self, args={}, params={}):
        """"""
        url = "tor/service/restart/"
        data = {}

        data = self._post( url, args)
        return data

    def start(self, args={}, params={}):
        """"""
        url = "tor/service/start/"
        data = {}

        data = self._post( url, args)
        return data

    def status(self, args={}, params={}):
        """"""
        url = "tor/service/status/"
        data = {}

        data = self._get( url, args)
        return data

    def stop(self, args={}, params={}):
        """"""
        url = "tor/service/stop/"
        data = {}

        data = self._post( url, args)
        return data

    def streams(self, args={}, params={}):
        """"""
        url = "tor/service/streams/"
        data = {}

        data = self._get( url, args)
        return data

class tor_socksacl(client.BaseClient):
    """A client for interacting with the OPNSense's torsocksacl API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/security/tor/src/opnsense/mvc/app/models/OPNsense/Tor/ACLSocksPolicy.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addacl(self, args={}, params={}):
        """"""
        url = "tor/socksacl/addacl/"
        data = {}

        data = self._post( url, args)
        return data

    def delacl(self, args={}, params={}):
        """"""
        url = "tor/socksacl/delacl/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "tor/socksacl/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getacl(self, args={}, params={}):
        """"""
        url = "tor/socksacl/getacl/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchacl(self, args={}, params={}):
        """"""
        url = "tor/socksacl/searchacl/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "tor/socksacl/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setacl(self, args={}, params={}):
        """"""
        url = "tor/socksacl/setacl/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleacl(self, args={}, params={}):
        """"""
        url = "tor/socksacl/toggleacl/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data
